;; Generated package description from mode: lisp-data; .el  -*- triplesno-byte-compile: t -*-
(define-package "triples" "0.5.1" "A flexible triple-based database for use in apps" '((seq "2.0") (emacs "28.1")) :commit "3c42e4b3c891cfbc2dd32fe10d7fa82047027bc6" :authors '(("Andrew Hyatt" . "ahyatt@gmail.com")) :maintainer '("Andrew Hyatt" . "ahyatt@gmail.com") :keywords '("triples" "kg" "data" "sqlite") :url "https://github.com/ahyatt/triples")
